==> jc-1.4.0.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintServiceAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 530e18a6f2018917 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet.h <==
// class javax.print.attribute.AttributeSetUtilities$SynchronizedPrintServiceAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a977668ae8c65227 javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet
// @dep_class 530e18a6f2018917 javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet

#include "javax/print/attribute/AttributeSetUtilities__24SynchronizedAttributeSet.h"

#ifndef _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_
#define _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_attribute_PrintServiceAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object;

typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype;

// Constructors
extern void _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$method$_init$8dd1ca2c0646d12a(_jc_env *, struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vmethods	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs {
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_refs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedAttributeSet;
    _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$sub_nonrefs	javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$object {
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$vtype _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_AttributeSetUtilities__24SynchronizedPrintServiceAttributeSet_H_ */
